@@ -40,6 +40,7 @@ typedef enum
   COGL_ATTRIBUTE_NAME_ID_COLOR_ARRAY,
   COGL_ATTRIBUTE_NAME_ID_TEXTURE_COORD_ARRAY,
   COGL_ATTRIBUTE_NAME_ID_NORMAL_ARRAY,
+  COGL_ATTRIBUTE_NAME_ID_POINT_SIZE_ARRAY,
   COGL_ATTRIBUTE_NAME_ID_CUSTOM_ARRAY
 } CoglAttributeNameID;
 
@@ -126,5 +127,8 @@ _cogl_flush_attributes_state (CoglFramebuffer *framebuffer,
                               CoglAttribute **attributes,
                               int n_attributes);
 
+int
+_cogl_attribute_get_n_components (CoglAttribute *attribute);
+
 #endif /* __COGL_ATTRIBUTE_PRIVATE_H */
 
