@@ -30,12 +30,12 @@
 
 #include <X11/Xutil.h>
 
-G_BEGIN_DECLS
+COGL_BEGIN_DECLS
 
 #define cogl_clutter_winsys_xlib_get_visual_info cogl_clutter_winsys_xlib_get_visual_info_CLUTTER
 XVisualInfo *
 cogl_clutter_winsys_xlib_get_visual_info (void);
 
-G_END_DECLS
+COGL_END_DECLS
 
 #endif /* __COGL_CLUTTER_XLIB_H__ */
