@@ -29,6 +29,7 @@
 #endif
 
 #include <glib.h>
+#include <string.h>
 
 #include "cogl-util.h"
 #include "cogl-types.h"
@@ -46,7 +47,26 @@
 CoglBool
 cogl_clutter_check_extension (const char *name, const char *ext)
 {
-  return _cogl_check_extension (name, ext);
+  char *end;
+  int name_len, n;
+
+  if (name == NULL || ext == NULL)
+    return FALSE;
+
+  end = (char*)(ext + strlen(ext));
+
+  name_len = strlen(name);
+
+  while (ext < end)
+    {
+      n = strcspn(ext, " ");
+
+      if ((name_len == n) && (!strncmp(name, ext, n)))
+	return TRUE;
+      ext += (n + 1);
+    }
+
+  return FALSE;
 }
 
 CoglBool
