@@ -33,7 +33,7 @@
 
 #include <cogl/cogl-context.h>
 
-G_BEGIN_DECLS
+COGL_BEGIN_DECLS
 
 /**
  * SECTION:cogl-index-buffer
@@ -57,6 +57,8 @@ typedef struct _CoglIndexBuffer	      CoglIndexBuffer;
  * cogl_buffer_set_data() or by mapping it into the application's
  * address space using cogl_buffer_map().
  *
+ * Return value: (transfer full): A newly allocated #CoglIndexBuffer
+ *
  * Since: 1.4
  * Stability: Unstable
  */
@@ -79,7 +81,7 @@ cogl_index_buffer_new (CoglContext *context,
 CoglBool
 cogl_is_index_buffer (void *object);
 
-G_END_DECLS
+COGL_END_DECLS
 
 #endif /* __COGL_INDEX_BUFFER_H__ */
 
