@@ -27,6 +27,7 @@
 #include "cogl-texture.h"
 #include "cogl-object-private.h"
 #include "cogl-clip-stack.h"
+#include "cogl-fence-private.h"
 
 #define COGL_JOURNAL_VBO_POOL_SIZE 8
 
@@ -58,6 +59,8 @@ typedef struct _CoglJournal
 
   int fast_read_pixel_count;
 
+  CoglList pending_fences;
+
 } CoglJournal;
 
 /* To improve batching of geometry when submitting vertices to OpenGL we
