@@ -154,6 +154,8 @@ _cogl_journal_new (CoglFramebuffer *framebuffer)
   journal->entries = g_array_new (FALSE, FALSE, sizeof (CoglJournalEntry));
   journal->vertices = g_array_new (FALSE, FALSE, sizeof (float));
 
+  _cogl_list_init (&journal->pending_fences);
+
   return _cogl_journal_object_new (journal);
 }
 
@@ -1267,6 +1269,18 @@ _cogl_journal_all_entries_within_bounds (CoglJournal *journal,
   return TRUE;
 }
 
+static void
+post_fences (CoglJournal *journal)
+{
+  CoglFenceClosure *fence, *tmp;
+
+  _cogl_list_for_each_safe (fence, tmp, &journal->pending_fences, link)
+    {
+      _cogl_list_remove (&fence->link);
+      _cogl_fence_submit (fence);
+    }
+}
+
 /* XXX NB: When _cogl_journal_flush() returns all state relating
  * to pipelines, all glEnable flags and current matrix state
  * is undefined.
@@ -1290,7 +1304,10 @@ _cogl_journal_flush (CoglJournal *journal)
                      0 /* no application private data */);
 
   if (journal->entries->len == 0)
-    return;
+    {
+      post_fences (journal);
+      return;
+    }
 
   framebuffer = journal->framebuffer;
   ctx = framebuffer->context;
@@ -1388,6 +1405,8 @@ _cogl_journal_flush (CoglJournal *journal)
   _cogl_journal_discard (journal);
   COGL_TIMER_STOP (_cogl_uprof_context, discard_timer);
 
+  post_fences (journal);
+
   COGL_TIMER_STOP (_cogl_uprof_context, flush_timer);
 }
 
@@ -1436,6 +1455,12 @@ _cogl_journal_log_quad (CoglJournal  *journal,
 
   COGL_TIMER_START (_cogl_uprof_context, log_timer);
 
+  /* Adding something to the journal should mean that we are in the
+   * middle of the scene. Although this will also end up being set
+   * when the journal is actually flushed, we set it here explicitly
+   * so that we will know sooner */
+  _cogl_framebuffer_mark_mid_scene (framebuffer);
+
   /* If the framebuffer was previously empty then we'll take a
      reference to the current framebuffer. This reference will be
      removed when the journal is flushed */
