@@ -31,7 +31,7 @@
 #include <cogl/cogl-types.h>
 #include <cogl/cogl-renderer.h>
 
-G_BEGIN_DECLS
+COGL_BEGIN_DECLS
 
 /**
  * cogl_kms_renderer_get_kms_fd:
@@ -47,5 +47,5 @@ G_BEGIN_DECLS
 int
 cogl_kms_renderer_get_kms_fd (CoglRenderer *renderer);
 
-G_END_DECLS
+COGL_END_DECLS
 #endif /* __COGL_KMS_RENDERER_H__ */
