@@ -102,9 +102,9 @@ cogl_offscreen_new_with_texture (CoglTexture *texture);
  *   buffer.
  * Deprecated: 1.16: Use cogl_offscreen_new_with_texture instead.
  */
+COGL_DEPRECATED_IN_1_16_FOR (cogl_offscreen_new_with_texture)
 CoglOffscreen *
-cogl_offscreen_new_to_texture (CoglTexture *texture)
-    COGL_DEPRECATED_IN_1_16_FOR (cogl_offscreen_new_with_texture);
+cogl_offscreen_new_to_texture (CoglTexture *texture);
 
 /**
  * cogl_is_offscreen:
