@@ -44,25 +44,32 @@ typedef enum
   COGL_PRIVATE_FEATURE_TEXTURE_FORMAT_BGRA8888 = 1L<<8,
   COGL_PRIVATE_FEATURE_UNPACK_SUBIMAGE = 1L<<9,
   COGL_PRIVATE_FEATURE_SAMPLER_OBJECTS = 1L<<10,
-  COGL_PRIVATE_FEATURE_FIXED_FUNCTION = 1L<<11,
-  COGL_PRIVATE_FEATURE_READ_PIXELS_ANY_FORMAT = 1L<<12,
-  COGL_PRIVATE_FEATURE_ANY_GL = 1L<<13,
-  COGL_PRIVATE_FEATURE_ALPHA_TEST = 1L<<14,
-  COGL_PRIVATE_FEATURE_FORMAT_CONVERSION = 1L<<15,
-  COGL_PRIVATE_FEATURE_QUADS = 1L<<16,
-  COGL_PRIVATE_FEATURE_BLEND_CONSTANT = 1L<<17,
-  COGL_PRIVATE_FEATURE_QUERY_FRAMEBUFFER_BITS = 1L<<18,
-  COGL_PRIVATE_FEATURE_BUILTIN_POINT_SIZE_UNIFORM = 1L<<19,
-  COGL_PRIVATE_FEATURE_QUERY_TEXTURE_PARAMETERS = 1L<<20,
-  COGL_PRIVATE_FEATURE_ALPHA_TEXTURES = 1L<<21,
-  COGL_PRIVATE_FEATURE_TEXTURE_SWIZZLE = 1L<<22,
-  COGL_PRIVATE_FEATURE_TEXTURE_MAX_LEVEL = 1L<<23,
-  COGL_PRIVATE_FEATURE_OES_EGL_SYNC = 1L<<24,
+  COGL_PRIVATE_FEATURE_READ_PIXELS_ANY_FORMAT = 1L<<11,
+  COGL_PRIVATE_FEATURE_ALPHA_TEST = 1L<<12,
+  COGL_PRIVATE_FEATURE_FORMAT_CONVERSION = 1L<<13,
+  COGL_PRIVATE_FEATURE_QUADS = 1L<<14,
+  COGL_PRIVATE_FEATURE_BLEND_CONSTANT = 1L<<15,
+  COGL_PRIVATE_FEATURE_QUERY_FRAMEBUFFER_BITS = 1L<<16,
+  COGL_PRIVATE_FEATURE_BUILTIN_POINT_SIZE_UNIFORM = 1L<<17,
+  COGL_PRIVATE_FEATURE_QUERY_TEXTURE_PARAMETERS = 1L<<18,
+  COGL_PRIVATE_FEATURE_ALPHA_TEXTURES = 1L<<19,
+  COGL_PRIVATE_FEATURE_TEXTURE_SWIZZLE = 1L<<20,
+  COGL_PRIVATE_FEATURE_TEXTURE_MAX_LEVEL = 1L<<21,
+  COGL_PRIVATE_FEATURE_ARBFP = 1L<<22,
+  COGL_PRIVATE_FEATURE_OES_EGL_SYNC = 1L<<23,
   /* If this is set then the winsys is responsible for queueing dirty
    * events. Otherwise a dirty event will be queued when the onscreen
    * is first allocated or when it is shown or resized */
-  COGL_PRIVATE_FEATURE_DIRTY_EVENTS = 1L<<25,
-  COGL_PRIVATE_FEATURE_ENABLE_PROGRAM_POINT_SIZE = 1L<<26
+  COGL_PRIVATE_FEATURE_DIRTY_EVENTS = 1L<<24,
+  COGL_PRIVATE_FEATURE_ENABLE_PROGRAM_POINT_SIZE = 1L<<25,
+  /* These features let us avoid conditioning code based on the exact
+   * driver being used and instead check for broad opengl feature
+   * sets that can be shared by several GL apis */
+  COGL_PRIVATE_FEATURE_ANY_GL = 1L<<26,
+  COGL_PRIVATE_FEATURE_GL_FIXED = 1L<<27,
+  COGL_PRIVATE_FEATURE_GL_PROGRAMMABLE = 1L<<28,
+  COGL_PRIVATE_FEATURE_GL_EMBEDDED = 1L<<29,
+  COGL_PRIVATE_FEATURE_GL_WEB = 1L<<30
 } CoglPrivateFeatureFlags;
 
 /* Sometimes when evaluating pipelines, either during comparisons or
