@@ -70,6 +70,7 @@ struct _CoglRenderer
 #endif
 
   CoglDriver driver;
+  CoglPrivateFeatureFlags private_feature_flags;
 #ifndef HAVE_DIRECTLY_LINKED_GL_LIBRARY
   GModule *libgl_module;
 #endif
@@ -89,6 +90,11 @@ struct _CoglRenderer
   void *winsys;
 };
 
+/* Mask of constraints that effect driver selection. All of the other
+ * constraints effect only the winsys selection */
+#define COGL_RENDERER_DRIVER_CONSTRAINTS \
+  COGL_RENDERER_CONSTRAINT_SUPPORTS_COGL_GLES2
+
 typedef CoglFilterReturn (* CoglNativeFilterFunc) (void *native_event,
                                                    void *data);
 
