@@ -29,6 +29,7 @@
 #define __COGL_SDL_H__
 
 #include <cogl/cogl-context.h>
+#include <cogl/cogl-onscreen.h>
 #include <SDL.h>
 
 #ifdef _MSC_VER
@@ -40,7 +41,7 @@
 #pragma comment (lib, "SDLmain.lib")
 #endif
 
-G_BEGIN_DECLS
+COGL_BEGIN_DECLS
 
 /**
  * SECTION:cogl-sdl
@@ -56,7 +57,7 @@ G_BEGIN_DECLS
  * this:
  * |[
  * MyAppData data;
- * GError *error = NULL;
+ * CoglError *error = NULL;
  *
  * data.ctx = cogl_sdl_context_new (SDL_USEREVENT, &error);
  * if (!data.ctx)
@@ -97,9 +98,9 @@ G_BEGIN_DECLS
 
 /**
  * cogl_sdl_context_new:
- * @type: An SDL user event type between %SDL_USEREVENT and
- *        %SDL_NUMEVENTS - %1
- * @error: A GError return location.
+ * @type: An SDL user event type between <constant>SDL_USEREVENT</constant> and
+ *        <constant>SDL_NUMEVENTS</constant> - 1
+ * @error: A CoglError return location.
  *
  * This is a convenience function for creating a new #CoglContext for
  * use with SDL and specifying what SDL user event type Cogl can use
@@ -132,13 +133,13 @@ G_BEGIN_DECLS
  * Stability: unstable
  */
 CoglContext *
-cogl_sdl_context_new (int type, GError **error);
+cogl_sdl_context_new (int type, CoglError **error);
 
 /**
  * cogl_sdl_renderer_set_event_type:
  * @renderer: A #CoglRenderer
- * @type: An SDL user event type between %SDL_USEREVENT and
- *        %SDL_NUMEVENTS - %1
+ * @type: An SDL user event type between <constant>SDL_USEREVENT</constant> and
+ *        <constant>SDL_NUMEVENTS</constant> - 1
  *
  * Tells Cogl what SDL user event type it can use as a way to
  * interrupt SDL_WaitEvent() to ensure that cogl_sdl_handle_event()
@@ -202,6 +203,22 @@ cogl_sdl_handle_event (CoglContext *context, SDL_Event *event);
 void
 cogl_sdl_idle (CoglContext *context);
 
-G_END_DECLS
+#if SDL_MAJOR_VERSION >= 2
+
+/**
+ * cogl_sdl_onscreen_get_window:
+ * @onscreen: A #CoglOnscreen
+ *
+ * Returns: the underlying SDL_Window associated with an onscreen framebuffer.
+ *
+ * Since: 2.0
+ * Stability: unstable
+ */
+SDL_Window *
+cogl_sdl_onscreen_get_window (CoglOnscreen *onscreen);
+
+#endif /* SDL_MAJOR_VERSION */
+
+COGL_END_DECLS
 
 #endif /* __COGL_SDL_H__ */
