@@ -28,20 +28,17 @@
 #ifndef __COGL_SWAP_CHAIN_H__
 #define __COGL_SWAP_CHAIN_H__
 
-G_BEGIN_DECLS
+COGL_BEGIN_DECLS
 
 typedef struct _CoglSwapChain CoglSwapChain;
 
-#define cogl_swap_chain_new cogl_swap_chain_new_EXP
 CoglSwapChain *
 cogl_swap_chain_new (void);
 
-#define cogl_swap_chain_set_has_alpha cogl_swap_chain_set_has_alpha_EXP
 void
 cogl_swap_chain_set_has_alpha (CoglSwapChain *swap_chain,
                                CoglBool has_alpha);
 
-#define cogl_swap_chain_set_length cogl_swap_chain_set_length_EXP
 void
 cogl_swap_chain_set_length (CoglSwapChain *swap_chain,
                             int length);
@@ -49,6 +46,6 @@ cogl_swap_chain_set_length (CoglSwapChain *swap_chain,
 CoglBool
 cogl_is_swap_chain (void *object);
 
-G_END_DECLS
+COGL_END_DECLS
 
 #endif /* __COGL_SWAP_CHAIN_H__ */
