@@ -25,6 +25,8 @@
 #include "config.h"
 #endif
 
+#include <string.h>
+
 #include "cogl-util.h"
 #include "cogl-private.h"
 
@@ -151,8 +153,8 @@ _cogl_util_pixel_format_from_masks_real (unsigned long r_mask,
                                          unsigned long g_mask,
                                          unsigned long b_mask,
                                          int depth, int bpp,
-                                         gboolean check_bgr,
-                                         gboolean check_afirst,
+                                         CoglBool check_bgr,
+                                         CoglBool check_afirst,
                                          int recursion_depth)
 {
   CoglPixelFormat image_format;
@@ -220,7 +222,7 @@ _cogl_util_pixel_format_from_masks (unsigned long r_mask,
                                     unsigned long g_mask,
                                     unsigned long b_mask,
                                     int depth, int bpp,
-                                    gboolean byte_order_is_lsb_first)
+                                    CoglBool byte_order_is_lsb_first)
 {
   CoglPixelFormat image_format =
     _cogl_util_pixel_format_from_masks_real (r_mask, g_mask, b_mask,
@@ -252,4 +254,26 @@ _cogl_util_pixel_format_from_masks (unsigned long r_mask,
   return image_format;
 }
 
+#ifndef HAVE_MEMMEM
+
+char *
+_cogl_util_memmem (const void *haystack,
+                   size_t haystack_len,
+                   const void *needle,
+                   size_t needle_len)
+{
+  size_t i;
+
+  if (needle_len > haystack_len)
+    return NULL;
+
+  for (i = 0; i <= haystack_len - needle_len; i++)
+    if (!memcmp ((const char *) haystack + i, needle, needle_len))
+      return (char *) haystack + i;
+
+  return NULL;
+}
+
+#endif /* HAVE_MEMMEM */
+
 #endif /* _COGL_IN_TEST_BITMASK */
