@@ -38,6 +38,7 @@
 #include "cogl-x11-renderer-private.h"
 #include "cogl-winsys-private.h"
 #include "cogl-error-private.h"
+#include "cogl-poll-private.h"
 
 #include <X11/Xlib.h>
 #include <X11/extensions/Xdamage.h>
@@ -238,7 +239,7 @@ update_outputs (CoglRenderer *renderer,
 
   _cogl_xlib_renderer_trap_errors (renderer, &state);
 
-  for (i = 0; i < resources->ncrtc && !error; i++)
+  for (i = 0; resources && i < resources->ncrtc && !error; i++)
     {
       XRRCrtcInfo *crtc_info = NULL;
       XRROutputInfo *output_info = NULL;
@@ -467,6 +468,32 @@ randr_filter (XEvent *event,
   return COGL_FILTER_CONTINUE;
 }
 
+static int64_t
+prepare_xlib_events_timeout (void *user_data)
+{
+  CoglRenderer *renderer = user_data;
+  CoglXlibRenderer *xlib_renderer = _cogl_xlib_renderer_get_data (renderer);
+
+  return XPending (xlib_renderer->xdpy) ? 0 : -1;
+}
+
+static void
+dispatch_xlib_events (void *user_data, int revents)
+{
+  CoglRenderer *renderer = user_data;
+  CoglXlibRenderer *xlib_renderer = _cogl_xlib_renderer_get_data (renderer);
+
+  if (renderer->xlib_enable_event_retrieval)
+    while (XPending (xlib_renderer->xdpy))
+      {
+        XEvent xevent;
+
+        XNextEvent (xlib_renderer->xdpy, &xevent);
+
+        cogl_xlib_renderer_handle_event (renderer, &xevent);
+      }
+}
+
 CoglBool
 _cogl_xlib_renderer_connect (CoglRenderer *renderer, CoglError **error)
 {
@@ -497,8 +524,15 @@ _cogl_xlib_renderer_connect (CoglRenderer *renderer, CoglError **error)
 
   xlib_renderer->trap_state = NULL;
 
-  xlib_renderer->poll_fd.fd = ConnectionNumber (xlib_renderer->xdpy);
-  xlib_renderer->poll_fd.events = COGL_POLL_FD_EVENT_IN;
+  if (renderer->xlib_enable_event_retrieval)
+    {
+      _cogl_poll_renderer_add_fd (renderer,
+                                  ConnectionNumber (xlib_renderer->xdpy),
+                                  COGL_POLL_FD_EVENT_IN,
+                                  prepare_xlib_events_timeout,
+                                  dispatch_xlib_events,
+                                  renderer);
+    }
 
   XRRSelectInput(xlib_renderer->xdpy,
                  DefaultRootWindow (xlib_renderer->xdpy),
@@ -568,47 +602,20 @@ cogl_xlib_renderer_remove_filter (CoglRenderer *renderer,
                                        (CoglNativeFilterFunc)func, data);
 }
 
-void
-_cogl_xlib_renderer_poll_get_info (CoglRenderer *renderer,
-                                   CoglPollFD **poll_fds,
-                                   int *n_poll_fds,
-                                   int64_t *timeout)
+int64_t
+_cogl_xlib_renderer_get_dispatch_timeout (CoglRenderer *renderer)
 {
   CoglXlibRenderer *xlib_renderer = _cogl_xlib_renderer_get_data (renderer);
 
   if (renderer->xlib_enable_event_retrieval)
     {
-      *n_poll_fds = 1;
-      *poll_fds = &xlib_renderer->poll_fd;
       if (XPending (xlib_renderer->xdpy))
-        *timeout = 0;
+        return 0;
       else
-        *timeout = -1;
+        return -1;
     }
   else
-    {
-      *n_poll_fds = 0;
-      *poll_fds = NULL;
-      *timeout = -1;
-    }
-}
-
-void
-_cogl_xlib_renderer_poll_dispatch (CoglRenderer *renderer,
-                                   const CoglPollFD *poll_fds,
-                                   int n_poll_fds)
-{
-  CoglXlibRenderer *xlib_renderer = _cogl_xlib_renderer_get_data (renderer);
-
-  if (renderer->xlib_enable_event_retrieval)
-    while (XPending (xlib_renderer->xdpy))
-      {
-        XEvent xevent;
-
-        XNextEvent (xlib_renderer->xdpy, &xevent);
-
-        cogl_xlib_renderer_handle_event (renderer, &xevent);
-      }
+    return -1;
 }
 
 CoglOutput *
