@@ -29,17 +29,15 @@
 #define __COGL_XLIB_RENDERER_H__
 
 #include <X11/Xlib.h>
-#include <glib.h>
 
 #define __COGL_H_INSIDE__
 #include <cogl/cogl-renderer.h>
 
-G_BEGIN_DECLS
+COGL_BEGIN_DECLS
 
-#define cogl_xlib_renderer_handle_event \
-  cogl_xlib_renderer_handle_event_EXP
 /*
  * cogl_xlib_renderer_handle_event:
+ * @renderer: a #CoglRenderer
  * @event: pointer to an XEvent structure
  *
  * This function processes a single event; it can be used to hook into
@@ -59,7 +57,7 @@ cogl_xlib_renderer_handle_event (CoglRenderer *renderer,
 /*
  * CoglXlibFilterFunc:
  * @event: pointer to an XEvent structure
- * @data: The data that was given when the filter was added
+ * @data: the data that was given when the filter was added
  *
  * A callback function that can be registered with
  * cogl_xlib_renderer_add_filter(). The function should return
@@ -69,9 +67,11 @@ cogl_xlib_renderer_handle_event (CoglRenderer *renderer,
 typedef CoglFilterReturn (* CoglXlibFilterFunc) (XEvent *event,
                                                  void *data);
 
-#define cogl_xlib_renderer_add_filter cogl_xlib_renderer_add_filter_EXP
 /*
  * cogl_xlib_renderer_add_filter:
+ * @renderer: a #CoglRenderer
+ * @func: the callback function
+ * @data: user data passed to @func when called
  *
  * Adds a callback function that will receive all native events. The
  * function can stop further processing of the event by return
@@ -82,10 +82,11 @@ cogl_xlib_renderer_add_filter (CoglRenderer *renderer,
                                CoglXlibFilterFunc func,
                                void *data);
 
-#define cogl_xlib_renderer_remove_filter \
-  cogl_xlib_renderer_remove_filter_EXP
 /*
  * cogl_xlib_renderer_remove_filter:
+ * @renderer: a #CoglRenderer
+ * @func: the callback function
+ * @data: user data given when the callback was installed
  *
  * Removes a callback that was previously added with
  * cogl_xlib_renderer_add_filter().
@@ -95,10 +96,9 @@ cogl_xlib_renderer_remove_filter (CoglRenderer *renderer,
                                   CoglXlibFilterFunc func,
                                   void *data);
 
-#define cogl_xlib_renderer_get_foreign_display \
-  cogl_xlib_renderer_get_foreign_display_EXP
 /*
  * cogl_xlib_renderer_get_foreign_display:
+ * @renderer: a #CoglRenderer
  *
  * Return value: the foreign Xlib display that will be used by any Xlib based
  * winsys backend. The display needs to be set with
@@ -107,10 +107,9 @@ cogl_xlib_renderer_remove_filter (CoglRenderer *renderer,
 Display *
 cogl_xlib_renderer_get_foreign_display (CoglRenderer *renderer);
 
-#define cogl_xlib_renderer_set_foreign_display \
-  cogl_xlib_renderer_set_foreign_display_EXP
 /*
  * cogl_xlib_renderer_set_foreign_display:
+ * @renderer: a #CoglRenderer
  *
  * Sets a foreign Xlib display that Cogl will use for and Xlib based winsys
  * backend.
@@ -127,7 +126,7 @@ cogl_xlib_renderer_set_foreign_display (CoglRenderer *renderer,
 
 /**
  * cogl_xlib_renderer_set_event_retrieval_enabled:
- * @renderer: A #CoglRenderer
+ * @renderer: a #CoglRenderer
  * @enable: The new value
  *
  * Sets whether Cogl should automatically retrieve events from the X
@@ -146,10 +145,9 @@ void
 cogl_xlib_renderer_set_event_retrieval_enabled (CoglRenderer *renderer,
                                                 CoglBool enable);
 
-#define cogl_xlib_renderer_get_display cogl_xlib_renderer_get_display_EXP
 Display *
 cogl_xlib_renderer_get_display (CoglRenderer *renderer);
 
-G_END_DECLS
+COGL_END_DECLS
 
 #endif /* __COGL_XLIB_RENDERER_H__ */
