@@ -46,9 +46,9 @@ COGL_BEGIN_DECLS
  * Stability: Unstable
  * Deprecated: 1.16: Use cogl_xlib_renderer_get_display() instead
  */
+COGL_DEPRECATED_IN_1_16_FOR (cogl_xlib_renderer_get_display)
 Display *
-cogl_xlib_get_display (void)
-     COGL_DEPRECATED_IN_1_16_FOR (cogl_xlib_renderer_get_display);
+cogl_xlib_get_display (void);
 
 /*
  * cogl_xlib_set_display:
@@ -61,9 +61,9 @@ cogl_xlib_get_display (void)
  * Deprecated: 1.16: Use cogl_xlib_renderer_set_foreign_display()
  *                   instead
  */
+COGL_DEPRECATED_IN_1_16_FOR (cogl_xlib_renderer_set_foreign_display)
 void
-cogl_xlib_set_display (Display *display)
-     COGL_DEPRECATED_IN_1_16_FOR (cogl_xlib_renderer_set_foreign_display);
+cogl_xlib_set_display (Display *display);
 
 /*
  * cogl_xlib_handle_event:
@@ -83,9 +83,9 @@ cogl_xlib_set_display (Display *display)
  * Stability: Unstable
  * Deprecated: 1.16: Use cogl_xlib_renderer_handle_event() instead
  */
+COGL_DEPRECATED_IN_1_16_FOR (cogl_xlib_renderer_handle_event)
 CoglFilterReturn
-cogl_xlib_handle_event (XEvent *xevent)
-     COGL_DEPRECATED_IN_1_16_FOR (cogl_xlib_renderer_handle_event);
+cogl_xlib_handle_event (XEvent *xevent);
 
 COGL_END_DECLS
 
