@@ -224,6 +224,7 @@ _cogl_driver_update_features (CoglContext *context,
 
   context->glsl_major = 1;
   context->glsl_minor = 0;
+  context->glsl_version_to_use = 100;
 
   _cogl_gpu_info_init (context, &context->gpu);
 
@@ -262,7 +263,7 @@ _cogl_driver_update_features (CoglContext *context,
       private_flags |= COGL_PRIVATE_FEATURE_BLEND_CONSTANT;
     }
   else if (context->driver == COGL_DRIVER_GLES1)
-    private_flags |= (COGL_PRIVATE_FEATURE_FIXED_FUNCTION |
+    private_flags |= (COGL_PRIVATE_FEATURE_GL_FIXED |
                       COGL_PRIVATE_FEATURE_ALPHA_TEST |
                       COGL_PRIVATE_FEATURE_BUILTIN_POINT_SIZE_UNIFORM);
 
