@@ -111,7 +111,9 @@ typedef struct _CoglWinsysVtable
   (*onscreen_bind) (CoglOnscreen *onscreen);
 
   void
-  (*onscreen_swap_buffers) (CoglOnscreen *onscreen);
+  (*onscreen_swap_buffers_with_damage) (CoglOnscreen *onscreen,
+                                        const int *rectangles,
+                                        int n_rectangles);
 
   void
   (*onscreen_update_swap_throttled) (CoglOnscreen *onscreen);
@@ -154,16 +156,6 @@ typedef struct _CoglWinsysVtable
   (*onscreen_win32_get_window) (CoglOnscreen *onscreen);
 #endif
 
-  void
-  (*poll_get_info) (CoglContext *context,
-                    CoglPollFD **poll_fds,
-                    int *n_poll_fds,
-                    int64_t *timeout);
-  void
-  (*poll_dispatch) (CoglContext *context,
-                    const CoglPollFD *poll_fds,
-                    int n_poll_fds);
-
 #ifdef COGL_HAS_XLIB_SUPPORT
   CoglBool
   (*texture_pixmap_x11_create) (CoglTexturePixmapX11 *tex_pixmap);
@@ -193,6 +185,15 @@ typedef struct _CoglWinsysVtable
   void
   (*destroy_gles2_context) (CoglGLES2Context *gles2_ctx);
 
+  void *
+  (*fence_add) (CoglContext *ctx);
+
+  CoglBool
+  (*fence_is_complete) (CoglContext *ctx, void *fence);
+
+  void
+  (*fence_destroy) (CoglContext *ctx, void *fence);
+
 } CoglWinsysVtable;
 
 CoglBool
