@@ -26,7 +26,7 @@ redraw (Data *data)
   cogl_framebuffer_push_matrix (fb);
   cogl_framebuffer_translate (fb, data->center_x, -data->center_y, 0.0f);
 
-  cogl_framebuffer_draw_primitive (fb, data->pipeline, data->triangle);
+  cogl_primitive_draw (data->triangle, fb, data->pipeline);
   cogl_framebuffer_pop_matrix (fb);
 
   cogl_onscreen_swap_buffers (COGL_ONSCREEN (fb));
